@@ -86,6 +86,7 @@ B<NB>: This will not remove the JOINs or JOIN ON clauses.
 
 sub reset {
     my $me = shift;
+    $me->finish;
     $me->unwhere;
 #    $me->{IsDistinct} = 0;
     $me->show;
@@ -119,16 +120,13 @@ sub _table_alias {
     return undef if $me == $tbl; # This means it's checking for an aliased column
     my $i = $me->_table_idx($tbl);
     ouch 'The table is not in this query' unless defined $i;
-    # TODO: Use table aliases, when there's more than 1 table or column aliases are used
-#    @{$me->{Tables}} > 1 || @{$me->{build_data}{Showing}} ? 't'.($i + 1) : ();
-    # FIXME: Don't use aliases, when there's only 1 table - This breaks the Row 'from'
+    # Don't use aliases, when there's only 1 table
     @{$me->{Tables}} > 1 ? 't'.($i + 1) : ();
 }
 
 =head3 C<column>
 
-  $query->column($column_name);
-  $query->column($column_or_alias_name, 1);
+  $query->column($alias_or_column_name);
 
 Returns a reference to a column for use with other methods.
 
@@ -136,6 +134,7 @@ Returns a reference to a column for use with other methods.
 
 sub column {
     my ($me, $col, $_check_aliases) = @_;
+    $_check_aliases = $me->_alias_preference('column') unless defined $_check_aliases;
     my $column;
     return $column if $_check_aliases == 1 and $column = $me->_check_alias($col);
     for my $tbl ($me->tables) {
@@ -264,7 +263,7 @@ sub join_on {
     # Validate the fields
     for my $c (@$col1, @$col2) {
         if (blessed $c and $c->isa('DBIx::DBO::Column')) {
-            ouch 'Invalid table field' unless defined $me->_table_idx($c->[0]);
+            $me->_valid_col($c);
         } elsif (my $type = ref $c) {
             ouch 'Invalid value type: '.$type;
         }
@@ -394,7 +393,7 @@ sub where {
     # Validate the fields
     for my $f (@$fld, @$val) {
         if (blessed $f and $f->isa('DBIx::DBO::Column')) {
-            ouch 'Invalid table field' unless defined $me->_table_idx($f->[0]);
+            $me->_valid_col($f);
         } elsif (my $type = ref $f) {
             ouch 'Invalid value type: '.$type;
         }
@@ -522,16 +521,6 @@ sub _add_where {
     push @{$ref}, [ $op, $fld, $fld_func, $fld_opt, $val, $val_func, $val_opt, $opt{FORCE} ];
 }
 
-# In some cases column aliases can be used, but this differs by DB and where in the statement it's used.
-# The $method is the method we were called from: (join_on|where|having|_del_where|order_by|group_by)
-# This method provides a way for DBs to override the default which is always 1 except for join_on.
-# Return values: 0 = Don't use aliases, 1 = Check aliases then columns, 2 = Check columns then aliases
-sub _alias_preference {
-    my $me = shift;
-    my $method = shift;
-    return $method eq 'join_on' ? 0 : 1;
-}
-
 sub _parse_col_val {
     my $me = shift;
     my $col = shift;
@@ -631,7 +620,7 @@ sub having {
     # Validate the fields
     for my $f (@$fld, @$val) {
         if (blessed $f and $f->isa('DBIx::DBO::Column')) {
-            ouch 'Invalid table field' unless defined $me->_table_idx($f->[0]) or $f->[0] eq $me;
+            $me->_valid_col($f);
         } elsif (my $type = ref $f) {
             ouch 'Invalid value type: '.$type;
         }
@@ -1058,7 +1047,7 @@ Assume you want to create a C<Query> and C<Row> class for a "Users" table:
       my $class = shift;
       my $dbo = shift;
       
-      my $self = $class->SUPER::new($dbo, 'Users'); # Create the Query for the "Users" table only
+      my $self = $class->SUPER::new($dbo, 'Users'); # Create the Query for the "Users" table
       
       # We could even add some JOINs or other clauses here
       
