@@ -65,7 +65,7 @@ Return a list of C<Table> objects, which will always be this C<Table> object.
 =cut
 
 sub tables {
-    $_[0];
+    wantarray ? $_[0] : 1;
 }
 
 sub _table_alias {
@@ -95,6 +95,11 @@ sub column {
     $me->{Column}{$col} ||= bless [$me, $col], 'DBIx::DBO::Column';
 }
 
+sub _valid_col {
+    my ($me, $col) = @_;
+    return $col if $col->[0] == $me;
+}
+
 =head3 C<row>
 
 Returns a new L<DBIx::DBO::Row|DBIx::DBO::Row> object for this table.
